"""
Interact with systemd tools and services.
"""

import subprocess
import json

def list_timezones():
    """
    Just return a list of available timezones
    """
    timezones = subprocess.check_output(["/usr/bin/timezonectl", "list-timezones",
                                            ]).decode("utf-8").split("\n")
    return timezones

