"""
networking functions for for dmm.
"""

def set_chroot_hostname(chroot, hostname):
    """
    Writes a hostname in a chroot
    Could be replaced by writefile?
    """
    text_file = open(chroot + "/etc/hostname", "w")
    hostname_write = text_file.write(hostname)
    text_file.close()

