"""
timezone functions for for dmm.
"""

from command_runner import command_runner

def list_timezones():
    """
    Use systemd to list all timezones.
    """
    ecode, result = command_runner("timedatectl list-timezones")
    return (ecode, result)


def set_timezone(timezone):
    """
    Set a timezone
    """
    print("doesn't actually do anything yet")

