"""
debian functions for for dmm.
"""

import subprocess
from command_runner import command_runner

def update_sources(sources_list, sources_file, update_sources, chroot):
    """
    Update sources.list and optionally perform an apt-get update.
    """
    text_file = open(chroot + sources_file, "w")
    sources_write = text_file.write(sources_list)
    text_file.close()
    if update_sources:
        ecode, result = command_runner("chroot %s apt-get -q update" % (chroot),
                                shell=True)
        return ecode, result

